searchData={"items":[{"type":"module","title":"SimpleSchemaContext.FormHelper","doc":"Provides helper functions for working with forms and associations in Ecto changesets.\n\nThis module contains utilities for handling many-to-many relationships,\ntransforming entities to options for select inputs, and other common form operations.","ref":"SimpleSchemaContext.FormHelper.html"},{"type":"function","title":"SimpleSchemaContext.FormHelper.add_nil_option/2","doc":"","ref":"SimpleSchemaContext.FormHelper.html#add_nil_option/2"},{"type":"function","title":"SimpleSchemaContext.FormHelper.entities_to_options/2","doc":"","ref":"SimpleSchemaContext.FormHelper.html#entities_to_options/2"},{"type":"function","title":"SimpleSchemaContext.FormHelper.entity_to_option/2","doc":"","ref":"SimpleSchemaContext.FormHelper.html#entity_to_option/2"},{"type":"function","title":"SimpleSchemaContext.FormHelper.maybe_mark_for_deletion/1","doc":"","ref":"SimpleSchemaContext.FormHelper.html#maybe_mark_for_deletion/1"},{"type":"function","title":"SimpleSchemaContext.FormHelper.maybe_put_assoc/3","doc":"","ref":"SimpleSchemaContext.FormHelper.html#maybe_put_assoc/3"},{"type":"function","title":"SimpleSchemaContext.FormHelper.maybe_put_assoc/4","doc":"","ref":"SimpleSchemaContext.FormHelper.html#maybe_put_assoc/4"},{"type":"function","title":"SimpleSchemaContext.FormHelper.maybe_put_many_assoc/3","doc":"","ref":"SimpleSchemaContext.FormHelper.html#maybe_put_many_assoc/3"},{"type":"module","title":"SimpleSchemaContext.QueryHelper","doc":"Provides helper functions for building and manipulating Ecto queries.\n\nThis module contains utilities for applying filters to queries based on\nparameters from forms or API requests. It supports filtering by associations,\nmap fields, comparison operators, and more complex conditions.","ref":"SimpleSchemaContext.QueryHelper.html"},{"type":"function","title":"SimpleSchemaContext.QueryHelper.apply_filters/3","doc":"","ref":"SimpleSchemaContext.QueryHelper.html#apply_filters/3"},{"type":"module","title":"SimpleSchemaContext.Schema","doc":"Core module that provides a set of standard context functions for Phoenix schemas.\n  \n  When used, it automatically imports all the necessary Ecto modules and defines\n  a complete set of CRUD operations for the schema:\n  \n  * `list/0` and `list/2` - List all records with optional filtering\n  * `list_by_ids/2` - Fetch records by IDs\n  * `fetch/2` - Get a single record with error handling\n  * `get!/2` - Get a single record or raise if not found\n  * `create/2` - Create a new record\n  * `update/3` - Update an existing record\n  * `change/3` - Create a changeset for a record\n  * `delete/2` - Delete a record","ref":"SimpleSchemaContext.Schema.html"},{"type":"module","title":"Options - SimpleSchemaContext.Schema","doc":"When using this module, you must provide the following options:\n  \n  * `:repo` - The Ecto.Repo module to use for database operations","ref":"SimpleSchemaContext.Schema.html#module-options"},{"type":"module","title":"Example - SimpleSchemaContext.Schema","doc":"defmodule MyApp.Blog.Post do\n        use SimpleSchemaContext.Schema, repo: MyApp.Repo\n        \n        schema \"posts\" do\n          field :title, :string\n          field :body, :text\n          \n          timestamps()\n        end\n        \n        def changeset(post, attrs) do\n          post\n          |> cast(attrs, [:title, :body])\n          |> validate_required([:title, :body])\n        end\n      end","ref":"SimpleSchemaContext.Schema.html#module-example"},{"type":"behaviour","title":"SimpleSchemaContext.Schema.Behaviour","doc":"Defines the behaviour that all schemas using SimpleSchemaContext must implement.\n\nThis module specifies the contract for common database operations like listing,\nfetching, creating, updating, and deleting entities. It ensures that all schemas\nusing SimpleSchemaContext provide a consistent API.","ref":"SimpleSchemaContext.Schema.Behaviour.html"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.change/3","doc":"Creates a changeset for the given entity and attributes.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:change/3"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.changeset/2","doc":"Creates a changeset for validating the given entity with the provided attributes.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:changeset/2"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.create/2","doc":"Creates a new entity with the given attributes.\n\nReturns `{:ok, entity}` if successful, or `{:error, changeset}` if validation fails.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:create/2"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.delete/2","doc":"Deletes the given entity.\n\nReturns `{:ok, entity}` if successful, or `{:error, changeset}` if deletion fails.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:delete/2"},{"type":"type","title":"SimpleSchemaContext.Schema.Behaviour.entity/0","doc":"Represents an entity or schema record, which can be a struct or a tuple of structs.","ref":"SimpleSchemaContext.Schema.Behaviour.html#t:entity/0"},{"type":"type","title":"SimpleSchemaContext.Schema.Behaviour.entity_id/0","doc":"The ID of an entity, which can be an integer or a binary (UUID).","ref":"SimpleSchemaContext.Schema.Behaviour.html#t:entity_id/0"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.fetch/2","doc":"Fetches a single entity by the given criteria.\n\nReturns `{:ok, entity}` if found, or `{:error, :not_found}` if not found.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:fetch/2"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.full_preload/0","doc":"Returns a keyword list of all associations to preload for this entity.\n\nUsed for tests and similar places where we don't care about database performance.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:full_preload/0"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.get!/2","doc":"Gets a single entity by ID. Raises an error if not found.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:get!/2"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.list/0","doc":"Returns a list of all entities.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:list/0"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.list/2","doc":"Returns a filtered list of entities based on provided filters.\n\nFilters can include:\n- Simple equality: `%{\"name\" => \"John\"}`\n- Association filters: `%{\"author.name\" => \"Jane\"}`\n- Complex operators: `%{\"age\" => [\"gt\", 30]}`\n\nOptions can include:\n- `:preload` - associations to preload\n- `:limit` - maximum number of records to return\n- `:order_by` - sorting options\n- `:transformer` - function to transform results","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:list/2"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.list_by_ids/2","doc":"Returns a list of entities with the given IDs.\n\nOptions are the same as for `list/2`.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:list_by_ids/2"},{"type":"type","title":"SimpleSchemaContext.Schema.Behaviour.options/0","doc":"Options that can be passed to the various callback functions.","ref":"SimpleSchemaContext.Schema.Behaviour.html#t:options/0"},{"type":"callback","title":"SimpleSchemaContext.Schema.Behaviour.update/3","doc":"Updates an existing entity with the given attributes.\n\nReturns `{:ok, entity}` if successful, or `{:error, changeset}` if validation fails.","ref":"SimpleSchemaContext.Schema.Behaviour.html#c:update/3"},{"type":"extras","title":"Simple Schema Context","doc":"# Simple Schema Context\n\nA simple library to replace boilerplate Phoenix contexts with common CRUD operations. This library provides an easy way to standardize your contexts across a Phoenix application.","ref":"readme.html"},{"type":"extras","title":"Installation - Simple Schema Context","doc":"Add `simple_schema_context` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simple_schema_context, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting Started - Simple Schema Context","doc":"Create your schema module and use SimpleSchemaContext.Schema, providing your Repo module:\n\n```elixir\ndefmodule MyApp.Blog.Post do\n  use SimpleSchemaContext.Schema, repo: MyApp.Repo\n  \n  schema \"posts\" do\n    field :title, :string\n    field :body, :string\n    \n    timestamps()\n  end\n  \n  def changeset(post, attrs) do\n    post\n    |> cast(attrs, [:title, :body])\n    |> validate_required([:title, :body])\n  end\nend\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"Usage - Simple Schema Context","doc":"Once you've set up your schema, you can immediately use the built-in context functions:","ref":"readme.html#usage"},{"type":"extras","title":"Reading Data - Simple Schema Context","doc":"```elixir\n# List all records\nposts = Post.list()\n\n# Get a specific record (returns {:ok, post} or {:error, :not_found})\n{:ok, post} = Post.fetch(id: 123)\n\n# Get a specific record with preloads\n{:ok, post} = Post.fetch([id: 123], preload: [:comments, :author])\n\n# Get a record or raise an error\npost = Post.get!(123)\n\n# List with filtering (supports associations)\nposts = Post.list(%{\n  \"title\" => \"My Post\",                  # Filter by title\n  \"author.name\" => \"John\",               # Filter by association\n  \"metadata->published\" => true          # Filter by map field\n})\n\n# List with complex filters\nposts = Post.list(%{\n  \"title\" => [\"like\", \"Search Term\"],    # ILIKE search\n  \"views\" => [\"gt\", 100],                # Greater than\n  \"tags\" => [\"in\", [\"elixir\", \"phoenix\"]] # IN query\n})\n```","ref":"readme.html#reading-data"},{"type":"extras","title":"Creating and Updating - Simple Schema Context","doc":"```elixir\n# Create a new record\n{:ok, post} = Post.create(%{title: \"New Post\", body: \"Content\"})\n\n# Create with a custom changeset function\n{:ok, post} = Post.create(%{title: \"New Post\"}, changeset: &Post.custom_changeset/2)\n\n# Update a record\n{:ok, updated_post} = Post.update(post, %{title: \"Updated Title\"})\n\n# Get a changeset for validation\nchangeset = Post.change(post, %{title: \"\"})\n```","ref":"readme.html#creating-and-updating"},{"type":"extras","title":"Deleting - Simple Schema Context","doc":"```elixir\n{:ok, deleted_post} = Post.delete(post)\n```","ref":"readme.html#deleting"},{"type":"extras","title":"Form Helpers - Simple Schema Context","doc":"SimpleSchemaContext also includes helpers for form handling:\n\n```elixir\n# Transform entities to options for a select input\noptions = FormHelper.entities_to_options(users, label_key: :name)\n\n# Add a nil option to a select\noptions = FormHelper.add_nil_option(options, label: \"Select a user\")\n\n# Handle many-to-many relationships\ndef changeset(post, attrs) do\n  post\n  |> cast(attrs, [:title, :body])\n  |> validate_required([:title, :body])\n  |> maybe_put_many_assoc(:tags, &Tags.list_by_ids/1)\nend\n```","ref":"readme.html#form-helpers"},{"type":"extras","title":"License - Simple Schema Context","doc":"This library is released under the MIT License.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}